'use strict';

require('better-log/install');

var _jsdoc = require('./jsdoc');

var _jsdoc2 = _interopRequireDefault(_jsdoc);

var _typeAnnotationToJsdocType = require('./typeAnnotationToJsdocType');

var _typeAnnotationToJsdocType2 = _interopRequireDefault(_typeAnnotationToJsdocType);

var _jsdocParam = require('./jsdocParam');

var _jsdocParam2 = _interopRequireDefault(_jsdocParam);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function pluginAddJsdocAnnotations(_ref) {
    var t = _ref.types;

    return {
        visitor: {
            'FunctionDeclaration|FunctionExpression|ClassMethod': function FunctionDeclarationFunctionExpressionClassMethod(path, state) {
                var node = path.node;

                var tags = [];

                var name = node.key || node.id;
                if (name && name.name && name.name.startsWith('_')) {
                    tags.push({ title: 'private' });
                }

                if (node.params) {
                    node.params.forEach(function (param, i) {
                        (0, _jsdocParam2.default)(param, i, tags);
                    });
                }

                if (node.kind === 'get') {
                    var type = node.returnType && (0, _typeAnnotationToJsdocType2.default)(node.returnType.typeAnnotation);
                    tags.push({
                        title: 'type',
                        type: type
                    });
                } else if (node.returnType) {
                    tags.push({
                        title: 'returns',
                        type: (0, _typeAnnotationToJsdocType2.default)(node.returnType.typeAnnotation)
                    });
                }

                if (path.parentPath && (path.parentPath.isExportDefaultDeclaration() || path.parentPath.isExportNamedDeclaration())) {
                    (0, _jsdoc2.default)(path.parentPath, tags);
                } else {
                    (0, _jsdoc2.default)(path, tags);
                }
            }
        }
    };
};