'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = jsdoc;

var _tagNormalizer = require('./tagNormalizer');

var _tagNormalizer2 = _interopRequireDefault(_tagNormalizer);

var _jsdocNodeComment = require('./jsdocNodeComment');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function tagNameToString(tag) {
    if (!tag.name) {
        return tag.name;
    }

    if (tag.optional || tag.default !== undefined) {
        return '[' + tag.name + (tag.default !== undefined ? '=' + tag.default : '') + ']';
    }

    return tag.name;
}

function tagToString(tag) {
    return ['@' + tag.title, tag.type && '{' + tag.type + '}', tagNameToString(tag), tag.name && tag.description && '-', tag.description].filter(Boolean).join(' ');
}

function jsdoc(path, tags) {
    if (tags.length === 0) {
        return;
    }

    var jsdocComment = (0, _jsdocNodeComment.findOrCreateJsdoc)(path);
    jsdocComment.value = jsdocComment.value.trim();
    var parsedJsdoc = (0, _jsdocNodeComment.parseJsdoc)(jsdocComment.value);
    var parsedTags = parsedJsdoc && parsedJsdoc.tags.map(_tagNormalizer2.default);

    tags.forEach(function (tag) {
        tag = (0, _tagNormalizer2.default)(tag);

        var keys = ['title'];
        switch (tag.title) {
            case 'param':
                keys.push('name');
                break;
        }

        var existingTag = parsedTags.some(function (existingTag) {
            return keys.every(function (key) {
                return existingTag[key] === tag[key];
            });
        });

        if (!existingTag) {
            var stringTag = tagToString(tag);
            jsdocComment.value += '\r\n * ' + stringTag;
        }
    });
    jsdocComment.value += '\r\n';
}